function classif(nas,r,optdist,optclust,optcombi)

% CLASSIF plot dendrogram-euclidean, std euclidean, mahalanobis,kullback-leibler,cosine distance; linkage - NASC
%
% function classif(nas,r,optdist,optclust,optcombi)
% Classify and plot dendrogram of nas with r resolution
% ***Inputs:***
% nas -> object after distance.m
% r -> resolution
% **options:**
% optdist=1 euclidean distance; 2-std.euclidean; 3-kullback; 4-mahalanobis; 5-cosine
% optclust=1 ('average'), 2-single; 3-complete; 4-centroid; 5-ward
% optcombi=0 (simple distances); otherwise plot also combined chosen distance sum(s^2)_(n=1)^L
%
% (Based on function graphdendro 14Nov01)
% Susana Vinga - $v0.0 - 26Mar02 (not tested and only with euclidean)
% $v0.1 - 1Abr02; $v0.2 - 4Abr02 (mahalanobis%optcluster) $5Abr02
% Include cosine metric -> 24Mai02; put ; 16abr03

if nargin<3
   optdist=1;	%default: euclidean distance
end
if nargin<4
   optclust=1;	%default: average linkage
end
if nargin<5
   optcombi=0;
end

if (optdist==4) & ~isfield(nas,'mahalanobis')
   warning('Mahalanobis distance was not calculated!');
   return;
end


n=nas.L(r);

disp( strcat('Word length: ', num2str(n)) )

switch optdist
case 1
   y=nas.euclid{r};	%matrix of dissimilarity
   dist='Euclidean Distance';
   ext='euclid';		%extension
case 2
   y=nas.stdeuclid{r};
   dist='Standard Euclidean Distance'
   ext='stdeuclid';
case 3
   y=nas.kullback{r};
   dist='Kullback-Leibler'
   ext='kullback';
case 4
   y=nas.mahalanobis{r};
   dist='Mahalanobis Distance'
   ext='mahalanobis';
case 5
   y=nas.cos{r};
   dist='Cosine Distance '
   ext='cos';
otherwise
   disp('Distance option not valid');
   return
end

switch optclust
case 1
   clust='average';
case 2
   clust='single';
case 3
   clust='complete';
case 4
   clust='centroid';
case 5
   clust='ward';
otherwise
   disp('Linkage type not valid')
   return
end
  


y=isquareform(y);
z=linkage(y,clust);
disp(strcat(clust,' linkage used'))
c=cophenet(z,y)
d=dendrogram(z);
title(strcat(dist,' r=',num2str(r)));

if optcombi		%plot also combined distance
   y=0;
   d=eval( ['nas.' ext] );	%choosen distance 
   for i=1:length(nas.L)
      y=y+d{i}.^2;
   end
   figure;
   imagesc(y);colorbar;title([dist ' combined']);

   y=isquareform(y);
   z=linkage(y,clust);
   disp(strcat(clust,' linkage used'));
   c=cophenet(z,y)
   d=dendrogram(z);
   title( strcat(dist,' Combined distance') )
   
end


%print -dmfile euclid
%print -dpcx256 <filename>

%Additional..
%******1-testar subplot*********
%for i=1:m   %for each resolution
 %  y=sym(x(:,:,i))
  % y=isquareform(y)
   %z=linkage(y,'average')
   %c=cophenet(z,y)
   %subplot(t,1,i)
   %d=dendrogram(z)
   %legend(strcat('c=',num2str(c)))
%end
