function nas=distance(nas,opt)

% DISTANCE euclidean, std euclidean, mahalanobis (opt), kullback and cosine distances between sequences - NASC
%
% function nas=distance(nas,opt)
% adds fields: nas.euclid, nas.stdeuclid, nas.mahalanobis, nas.kullback
% nas.*{i}(j,k) -> *-distance (for ith resolution) between jth and kth sequence
% Susana Vinga, Mar02
% 12Mar02: comments and euclid
% Add std.euclidean -> 26Mar02
% Add Mahalanobis distance, chage counts to freqs -> 4Abr02
% Chage inverse to pseudoinverse in mahal.dist. (also for symbols) -> 5Abr02: better results.
% New option: if opt=1 (default) do Mahalanobis, otherwise don't do this distance -> 12Abr02
% Default distance function, add cosine metric (Stuart#55) -> 24Mai02
% comments - 16abr03

if nargin==1
   opt=1		%default: do
end


dim=2;	% euclidean norm or distance
ww=length(nas.words)	% how many resolutions
%ww=3 test lower dimensions

for i=1:ww	%for resolution i
   disp( ['Word length ',num2str(nas.L(i))] );
   c=nas.counts{i}; %columns - sequences; rows - words -> use frequencies instead of counts
   f=nas.freqs{i};	
   [p,q]=size(c);	% p - num of words; q - num of sequences
   L=sum(nas.counts{i});	%line vector with number of counted words for each sequence and resolution -> l do artigo
   
   %compare all possible pairs
   euclid=zeros(q,q);
   stdeuclid=zeros(q,q);
   kullback=zeros(q,q);
   if opt
      mahalanobis=zeros(q,q);
   end
   mcos=zeros(q,q);	%matrix of coseno distance
   
   %alternatively of teoric covariance, use sample cov.:
   %covari=cov(c');	%covariance defined for matrices where row=observation(sequence), columns=variable(n.words)
   
   for j=1:q
      for k=1:q
         if k>j
            euclid(j,k)=norm(f(:,j)-f(:,k),dim);
            stdeuclid(j,k)=norm( f(:,j)./nas.var{i}(:,j)-f(:,k)./nas.var{i}(:,k),dim);	%divide by std deviation -> use freqs instead of counts
            kullback(j,k)=h_rel(f(:,j),f(:,k));%verificar
            
            	%if i~=1	-> do also for symbols
            	%nas.cov{i}{j} covariance btw counts resol.i seq.j
            	if opt
   	         	n1=L(j);
               	n2=L(k);
          	   	%sigma pooled=((n1-1)*S1+(n2-2)*S2)/(n1+n2-2)
               	SIGMA= ( (n1-1)*nas.cov{i}{j} + (n2-1)*nas.cov{i}{k} )/(n1+n2-1) ;
              		%use PSEUDOINVERSE(sigma) because is nearly singular
               	mahalanobis(j,k)=(f(:,j)-f(:,k))'*pinv(SIGMA)*(f(:,j)-f(:,k));	
               end
            t=ang(f(:,j),f(:,k));	%angle between vectors
            mcos(j,k)=-log( (1+cos(t))/2 );	%dissimilarity on Stuart et al.
               
            %end
            
         elseif k<j
            kullback(j,k)=h_rel(f(:,j),f(:,k));	%is not symmetric
         end        
      end
   end
   
   nas.euclid{i}=euclid+euclid';	%symmetric matrix
   nas.stdeuclid{i}=stdeuclid+stdeuclid';
   nas.kullback{i}=kullback;
   nas.cos{i}=mcos+mcos';
   
   if opt
      nas.mahalanobis{i}=mahalanobis+mahalanobis';
   end
   
   
end %...for all resolutions i
