function nas=freqseq(nas,L)

% FREQSEQ subsequences or L words counts and frequencies of sequences - NASC
%
% function nas=freqseq(nas,L)
% Adds new fields to struct nas: words, counts and freqs
% Identifies all the unique segments
% of length L and stores its frequency
%
% Input arguments:
%   x: struct nas (.ref, .refs, .seq) 
%   L: vector of lengths, for example L=1:5
%
% Output arguments: nas.* - { 1x(number of sequences) cell} where * is:
%	nas.counts{i}(:,j) - word counts of j.ith sequence, ith word length 
%	nas.freqs{i}(:,j) - word frequence of j.ith sequence, ith word length 
%	nas.words{i} - char array: each row is a different word
%	nas.L{i} - word length of ith resolution
%
% v1.0: Jonas Almeida Nov 29 - 2001
% Adapted to Non Aligned Sequence Comparison: Susana Vinga, 4 Mar 2002
% Updated v2.0: Susana Vinga, 5 Mar 2002 - correction and comments; 12Mar02 - more comments and new field L;5Abr02

[s,t]=size(nas.seq); % t -  number of sequences
b=length(L); % b - resolutions i.e. possible word lengths

for ww=1:b %for each word length
   seq=[];% seq - data base: each row one word of the same length
	for j=1:t   % for all sequences
		x=nas.seq{j};	
		n=length(x); % length of sequence j
		if L(ww)>n
   		 warning('resolution decreased to the sequence length'); %avoied in practice
   	 	L(ww)=n;
		end
	
		%seq=[seq;x(1:1+L-1)];
		[p,q]=size(seq);   % p - actual number of words in data base
		c{j}=zeros(p,1);	% c{j} cell - counts for j-ith sequence
		for i=1:n-L(ww)+1			% runs all sequence, position i
   		 seqi=x(i:i+L(ww)-1);	% current word
  	  		 ii=strmatch(seqi,seq,'exact');	% ii: position (row number) where word begins<->strcmp
  	 	 	 if isempty(ii) % if sequence not already in the database
   		     seq=[seq;seqi];		% each row is a word
      		  c{j}=[c{j};1];
   		 else					% word already in data base
    		 		c{j}(ii)=c{j}(ii)+1;
   		 end
		end
		f{j}=c{j}./sum(c{j});
	 %  nas.counts{j}=c{j};   %each column has counts
	  %  nas.freqs{j}=f;	
	 end  %...of all sequences
	 
	 [p,q]=size(seq);% f - total number of words in data base after all sequence
	 
	 w{ww}=seq;	%w - cell with ww-ith words - char array
	 %!!!ATENTION!!! to assign a char array to a struct cell, the only way is to assign an intermediate step, i.e.
	 % to stuct field should be assign the COMPLETE cell!
	 
	  %counts=zeros(f,t);
	 %freqs=zeros(f,t);
    for j=1:t %create matrix of all counts, with zeros were word is absent
%       xaxa=[c{j};zeros(p-length(c{j}),1)]
	    counts(:,j)=[c{j};zeros(p-length(c{j}),1)];
	    freqs(:,j)=[f{j};zeros(p-length(f{j}),1)];
	 end
	 nas.counts{ww}=counts;	clear counts;	%matrix created is cell content
    nas.freqs{ww}=freqs; clear freqs;
 end   
 nas.L=L;
 nas.words=w;
	
 