function d=h_rel(x,y,opt)

% H_REL relative entropy and mutual information between two distributions - NASC
%
% function d=h_rel(x,y)
% RELATIVE ENTROPY D(p||q)=sum(-plog2(p/q)) or Kullback-Leibler distance.
% calculates D(p||q) of the probability mass function p with respect to the pmf q. 
% Also calculates MUTUAL INFORMATION I(X;Y)=sum(p(x,y)log(p(x,y)/p(x)p(y))): do x=p(x,y) and y=p(x)*p(y)
% Convenction (based on continuity): 0log(0/q)=0; plog(p/0)=inf
% opt=1, x,y already in probabilities, =0, not yet!
% Susana Vinga (svinga@itqb.unl.pt) 5/Nov/01; up:7/nov; 30/nov (comments)
% Included in Non-Aligned Sequence Comparision: 5 Mar 2002, up.12Mar02
% up 5Abr02

warning off;	%prevents erro msg from dividing by zero

p=x(:);
q=y(:);
if (nargin==3)&(opt==0)  % vectors are not in prob. form
   p=p/sum(p);           % normalize them
   q=q/sum(q);
end
tp=(p~=0);
tq=(q~=0); %where are the non-null probabilities
p=p(tp|tq);
q=q(tp|tq); %eliminate the null prob. they happen in the same points 

p(p==0)=1; %log0=1, correction continuos function

d=sum(p.*log2(p./q));

