function nas=nasc(txt,L,opt)

% NASC non aligned sequence comparision Toolbox
%
% function nas=nasc(txt,L)
% Complete function to perform non-aligned sequence comparison.
% txt -> text file with FASTA/USM format data
% L -> vector with word lengths
% opt -> 1 (def.) mahalanobis distance, 0 -> mahal. will not be calculated.
% 
% nas -> struct variable. Example: clf = 
%
%              ref: 'clfa'
%           refs: {1x7 cell  }
%            seq: {1x7 cell  }
%             tp: 'acgt'
%            num: [1x7 struct]
%           cgrs: [1x7 struct]
%         counts: {1x6 cell  }
%          freqs: {1x6 cell  }
%              L: [1 2 3 4 5 6]
%          words: {1x6 cell  }
%        overlap: {1x6 cell  }
%            var: {1x6 cell  }
%            cov: {1x6 cell  }
%         euclid: {1x6 cell  }
%      stdeuclid: {1x6 cell  }
%       kullback: {1x6 cell  }
%    mahalanobis: {1x6 cell  }
%            cov: {1x6 cell  }
%
% Calls: cgcria(txt); freqseq(nas,L); overlap(nas); nas=word_var(nas); nas=word_cov(nas);nas=distance(nas)
% See report for details about fields and help of functions called
% use plotdistance(nas) and classif(nas,+options) to see results
% Susana Vinga, 8 Mar 2002, 12Mar02; 5Abr02; 24Mai02


if nargin==2
   opt=1		%default: do mahalanobis distance
end

fprintf('Functions running\n\tcgcria\n');
nas=cgcria(txt);
fprintf('\tfreqseq\n');
nas=freqseq(nas,L);
fprintf('\toverlap\n');
nas=overlap(nas);
fprintf('\tword_var\n');
nas=word_var(nas);
fprintf('\tword_cov\n');

if opt 
   nas=word_cov(nas);
end

fprintf('\tdistance\n');
nas=distance(nas,opt);
