function plotdistance(nas,opt)

% PLOTDISTANCE plot euclidean, std euclid, mahalanobis, cosine and kullback distance between sequences - NASC
%
% function plotdistance(nas,opt)
% Plots euclidean, std euclid. mahal. and kullback-leibler distances between all sequences in nas
% opt=0 (default) don't print to file; 1-print figures to files euclid, kull, stdeuclid, mahal
% Susana Vinga, v0.0 12Mar02
% $v1.1, 26Mar02, adds option: print to file
% 4Abr02 (add mahal.dist.); 5Abr02; 24May02

% duvidas: how to have a general title in a subplot?
% como distinguir +inf de numeros elevados? (kullback)

if nargin==1
   opt=0;	%don't print to file (only to screen)
end

s=length(nas.L);	%s number of subplots
n=ceil(sqrt(s)*2^(-1/4));			%number of rows
m=ceil(s/n);			%number of colums

%**EUCLIDEAN**
figure;
title('Euclidean distance')	%no funciona
for i=1:s
   subplot(n,m,i);
   imagesc(nas.euclid{i});
   colorbar;
   title(['Euclidean Word length -> ',num2str(nas.L(i))]);
end
if opt
   print -dpcx256 euclid	%print to file euclid.m and euclid.mat
end

%**STANDARD EUCLIDEAN**
figure;
for i=1:s
   subplot(n,m,i);
   imagesc(nas.stdeuclid{i});
   colorbar;
   title(['Standard Euclidean distance: Word length -> ',num2str(nas.L(i))]);
end
if opt
   print -dpcx256 stdeucl	%print to file euclid.m and euclid.mat
end

%**KULLBACK-LEIBLER**
figure;
title('Kullback-Leibler discrepancy');
for i=1:s
   subplot(n,m,i);
   imagesc(nas.kullback{i});
   colorbar;
   title(['Kullback Word length -> ',num2str(nas.L(i))]);
end
if opt
   print -dpcx256 kull	%print to file euclid.m and euclid.mat
end

%**MAHALANOBIS**
if isfield(nas,'mahalanobis')	% mahalanobis distance was calculated previously
   figure;
   title('Mahalanobis distance');
   for i=1:s
      subplot(n,m,i);
      imagesc(nas.mahalanobis{i});
      colorbar;
      title(['Mahalanobis distance Word length -> ',num2str(nas.L(i))]);
   end
   if opt
      print -dpcx256 mahal	%print to file euclid.m and euclid.mat
   end
end

%**COSINE**
figure;
title('Cosine distance');
for i=1:s
   subplot(n,m,i);
   imagesc(nas.cos{i});
   colorbar;
   title(['Cosine Word length -> ',num2str(nas.L(i))]);
end
if opt
   print -dpcx256 cos	%print to file euclid.m and euclid.mat
end


%***ADD after doing crossd.m first to create nas.crossd
% while not implemented use plotdistance_usm instead
%figure;
%usm=nas.usm.normax; %not yet symmetric
%usm=usm+usm';	
%imagesc(usm);
%colorbar;
%title(['USM-based distance: norm max'])